Crate mrot_test_utils

Crate mrot_test_utils 

Library with helper functions and constructs used in the mrot test code.

Modules

argument
Contains the arguments used in test implementation and the instructions how to parse them from a string.
common_steps
A collection of test steps used in the tests of libmrot which are shared among test targets

Structs

World
World for cucumber tests

Enums

Error
Mrot error variants

Functions

debug_world
World where Scenarios are run in series and traces for debugging tests are output
debug_world_no_cleanup
World where Scenarios are run in series and traces for debugging tests are output. Cleanup procedure is not run after the scenario.
normal_world
Normal World
serial_world
World where Scenarios are run in series

Type Aliases

Result
Result type alias with mrot-test-util’s Error.