Module argument

Module argument 

Contains the arguments used in test implementation and the instructions how to parse them from a string.

Structs

DateString
By this we transform a timestamp string to a NaiveDate string.
MealRecords
Holds multiple MealRecords.
Meals
Holds multiple strings which are meals
NaiveDates
Holds multiple NaiveDates.
TextDate
Holds strings which are parsable date expressions
TextDates
Holds multiple TextDates.
WrappedPeriod
Wraps a Period so we can create it from a string from the feature files.