Error

Enum Error 

pub enum Error {
    LibMrot(Error),
    UndefinedValue(String),
    Chrono(ParseError),
    UnexpectedErrResult(String),
    TwoTimer(TimeError),
    StdNum(ParseIntError),
}
Mrot error variants

Variants



LibMrot(Error)



UndefinedValue(String)

Bug in the test code. Examples

  • a value in the World was supposed to be defined but wasn’t
  • a value was expected to be read from the feature file’s Examples table, but it wasn’t there


Chrono(ParseError)



UnexpectedErrResult(String)

Unexpected Err Result



TwoTimer(TimeError)



StdNum(ParseIntError)