Library with helper functions and constructs used in the mrot test code.
Modules
- argument
- Contains the arguments used in test implementation and the instructions how to parse them from a string.
- common_
steps - A collection of test steps used in the tests of libmrot which are shared among test targets
Structs
- World
- World for cucumber tests
Enums
- Error
- Mrot error variants
Functions
- debug_
world - World where Scenarios are run in series and traces for debugging tests are output
- debug_
world_ no_ cleanup - World where Scenarios are run in series and traces for debugging tests are output. Cleanup procedure is not run after the scenario.
- normal_
world - Normal World
- serial_
world - World where Scenarios are run in series
Type Aliases
- Result
- Result type alias with mrot-test-util’s Error.