Contains the arguments used in test implementation and the instructions how to parse them from a string.
Structs
- Date
String - By this we transform a timestamp string to a
NaiveDatestring. - Meal
Records - Holds multiple
MealRecords. - Meals
- Holds multiple strings which are meals
- Naive
Dates - Holds multiple
NaiveDates. - Text
Date - Holds strings which are parsable date expressions
- Text
Dates - Holds multiple
TextDates. - Wrapped
Period - Wraps a
Periodso we can create it from a string from the feature files.